@@ -1,22 +1,37 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2015-2019 Laurent Montel <montel@kde.org>
+    Copyright (c) 2015 Laurent Montel <montel@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "gendertest.h"
 #include "gender.h"
-#include "vcardtool_p.h"
-#include <QTest>
+#include "vcardtool.h"
+#include <qtest.h>
 
 GenderTest::GenderTest(QObject *parent)
     : QObject(parent)
 {
+
 }
 
 GenderTest::~GenderTest()
 {
+
 }
 
 void GenderTest::shouldHaveDefaultValue()
@@ -151,9 +166,9 @@ QByteArray GenderTest::createCard(const QByteArray &gender)
         expected += gender + "\r\n";
     }
     expected += QByteArray(
-        "N:;;;;\r\n"
-        "UID:testuid\r\n"
-        "END:VCARD\r\n\r\n");
+                    "N:;;;;\r\n"
+                    "UID:testuid\r\n"
+                    "END:VCARD\r\n\r\n");
     return expected;
 }
 
