@@ -1,7 +1,6 @@
 /*
     This file is part of the KContacts framework.
     Copyright (c) 2007 Tobias Koenig <tokoe@kde.org>
-    Copyright (C) 2016-2019 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -22,7 +21,7 @@
 #ifndef KEY_TEST_H
 #define KEY_TEST_H
 
-#include <QObject>
+#include <QtCore/QObject>
 
 class KeyTest : public QObject
 {
@@ -34,10 +33,6 @@ private Q_SLOTS:
     void differsTest();
     void assignmentTest();
     void serializeTest();
-    void shouldExportVCard3();
-    void shouldExportVCard4();
-    void shouldParseVcard3();
-    void shouldParseVcard4();
 };
 
 #endif
