@@ -1,22 +1,37 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2015-2019 Laurent Montel <montel@kde.org>
+    Copyright (c) 2015 Laurent Montel <montel@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "langtest.h"
 #include "lang.h"
-#include "vcardtool_p.h"
-#include <QTest>
+#include "vcardtool.h"
+#include <qtest.h>
 
 LangTest::LangTest(QObject *parent)
     : QObject(parent)
 {
+
 }
 
 LangTest::~LangTest()
 {
+
 }
 
 void LangTest::shouldHaveDefaultValue()
@@ -40,6 +55,7 @@ void LangTest::shouldAssignValue()
     QCOMPARE(language.language(), lang);
     QVERIFY(!language.parameters().isEmpty());
     QCOMPARE(language.parameters(), params);
+
 }
 
 void LangTest::shouldAssignExternal()
@@ -70,6 +86,7 @@ void LangTest::shouldSerialized()
     t >> result;
 
     QVERIFY(language == result);
+
 }
 
 void LangTest::shouldEqualLanguage()
@@ -93,7 +110,7 @@ void LangTest::shouldParseLanguage()
                          "VERSION:3.0\n"
                          "N:LastName;FirstName;;;\n"
                          "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\n"
-                         "LANG:fr\n"
+                         "LANG:fr"
                          "REV:2015-03-14T09:24:45+00:00\n"
                          "FN:FirstName LastName\n"
                          "END:VCARD\n");
@@ -102,7 +119,6 @@ void LangTest::shouldParseLanguage()
     const KContacts::AddresseeList lst = vcard.parseVCards(vcarddata);
     QCOMPARE(lst.count(), 1);
     QCOMPARE(lst.at(0).langs().count(), 1);
-    QCOMPARE(lst.at(0).langs().at(0).language(), QStringLiteral("fr"));
 }
 
 void LangTest::shouldParseWithoutLanguage()
@@ -169,6 +185,7 @@ void LangTest::shouldCreateVCardWithTwoLang()
                         "END:VCARD\r\n\r\n");
 
     QCOMPARE(ba, expected);
+
 }
 
 void LangTest::shouldCreateVCardWithParameters()
