@@ -19,11 +19,9 @@
 */
 
 #include "addressee.h"
-
 #include "converter/vcardconverter.h"
 
-#include <QTest>
-#include <QDebug>
+#include <qtest.h>
 #include <QDir>
 #include <QObject>
 
@@ -51,6 +49,7 @@ private Q_SLOTS:
 // check the validity of our test data set
 void RoundtripTest::initTestCase()
 {
+
     // check that all resource prefixes exist
 
     mInputDir = QDir(QStringLiteral(":/input"));
@@ -86,39 +85,18 @@ void RoundtripTest::testVCardRoundtrip_data()
     QString outFile21Pattern = QLatin1String("%1.2_1ref");
     QString outFile4Pattern = QLatin1String("v4_0.%1.ref");
     QString outFilePattern = QLatin1String("%1.ref");
-    for (const QString &inputFile : qAsConst(mInputFiles)) {
+    Q_FOREACH (const QString &inputFile, mInputFiles) {
         const QString outFile = outFilePattern.arg(inputFile);
         const QString outFileV2_1 = outFile21Pattern.arg(inputFile);
         const QString outFileV4 = outFile4Pattern.arg(inputFile);
         QTest::newRow(QFile::encodeName(inputFile).constData())
-            << inputFile
-            << (mOutput2_1Dir.exists(outFileV2_1) ? outFileV2_1 : QString())
-            << (mOutput3_0Dir.exists(outFile) ? outFile : QString())
-            << (mOutput4_0Dir.exists(outFileV4) ? outFileV4 : QString());
+                << inputFile
+                << (mOutput2_1Dir.exists(outFileV2_1) ? outFileV2_1 : QString())
+                << (mOutput3_0Dir.exists(outFile) ? outFile : QString())
+                << (mOutput4_0Dir.exists(outFileV4) ? outFileV4 : QString());
     }
 }
 
-static void compareBuffers(const char *version, const QByteArray &outputData, const QByteArray &outputRefData)
-{
-    if (outputData != outputRefData) {
-        qDebug() << " outputData " << outputData;
-        qDebug() << " outputRefData " << outputRefData;
-    }
-    const QList<QByteArray> outputLines = outputData.split('\n');
-    const QList<QByteArray> outputRefLines = outputRefData.split('\n');
-    for (int i = 0; i < qMin(outputLines.count(), outputRefLines.count()); ++i) {
-        const QByteArray &actual = outputLines.at(i);
-        const QByteArray &expect = outputRefLines.at(i);
-        if (actual != expect) {
-            qCritical() << "Mismatch in" << version << "output line" << (i + 1);
-            QCOMPARE(actual, expect);
-            QCOMPARE(actual.count(), expect.count());
-        }
-    }
-    QCOMPARE(outputLines.count(), outputRefLines.count());
-    QCOMPARE(outputData.size(), outputRefData.size());
-}
-
 void RoundtripTest::testVCardRoundtrip()
 {
     QFETCH(QString, inputFile);
@@ -148,7 +126,23 @@ void RoundtripTest::testVCardRoundtrip()
         QVERIFY(outputFile.open(QIODevice::ReadOnly));
 
         const QByteArray outputRefData = outputFile.readAll();
-        compareBuffers("v2.1", outputData, outputRefData);
+        QCOMPARE(outputData.size(), outputRefData.size());
+
+        const QList<QByteArray> outputLines = outputData.split('\n');
+        const QList<QByteArray> outputRefLines = outputRefData.split('\n');
+        QCOMPARE(outputLines.count(), outputRefLines.count());
+        for (int i = 0; i < outputLines.count(); ++i) {
+            const QByteArray actual = outputLines[i];
+            const QByteArray expect = outputRefLines[i];
+
+            if (actual != expect) {
+                qCritical() << "Mismatch in v2.1 output line" << (i + 1);
+                QCOMPARE(actual.count(), expect.count());
+
+                qCritical() << "\nActual:" << actual << "\nExpect:" << expect;
+                QCOMPARE(actual, expect);
+            }
+        }
     }
 
     if (!output3_0File.isEmpty()) {
@@ -158,7 +152,24 @@ void RoundtripTest::testVCardRoundtrip()
         QVERIFY(outputFile.open(QIODevice::ReadOnly));
 
         const QByteArray outputRefData = outputFile.readAll();
-        compareBuffers("v3.0", outputData, outputRefData);
+        QCOMPARE(outputData.size(), outputRefData.size());
+
+        const QList<QByteArray> outputLines = outputData.split('\n');
+        const QList<QByteArray> outputRefLines = outputRefData.split('\n');
+        QCOMPARE(outputLines.count(), outputRefLines.count());
+
+        for (int i = 0; i < outputLines.count(); ++i) {
+            const QByteArray actual = outputLines[i];
+            const QByteArray expect = outputRefLines[i];
+
+            if (actual != expect) {
+                qCritical() << "Mismatch in v3.0 output line" << (i + 1);
+
+                qCritical() << "\nActual:" << actual << "\nExpect:" << expect;
+                QCOMPARE(actual.count(), expect.count());
+                QCOMPARE(actual, expect);
+            }
+        }
     }
 #if 0
     if (!output4_0File.isEmpty()) {
@@ -168,7 +179,24 @@ void RoundtripTest::testVCardRoundtrip()
         QVERIFY(outputFile.open(QIODevice::ReadOnly));
 
         const QByteArray outputRefData = outputFile.readAll();
-        compareBuffers("v4.0", outputData, outputRefData);
+        //QCOMPARE( outputData.size(), outputRefData.size() );
+
+        const QList<QByteArray> outputLines = outputData.split('\n');
+        const QList<QByteArray> outputRefLines = outputRefData.split('\n');
+        //QCOMPARE(outputLines.count(), outputRefLines.count());
+
+        for (int i = 0; i < outputLines.count(); ++i) {
+            const QByteArray actual = outputLines[i];
+            const QByteArray expect = outputRefLines[i];
+
+            if (actual != expect) {
+                qCritical() << "Mismatch in v4.0 output line" << (i + 1);
+
+                qCritical() << "\nActual:" << actual << "\nExpect:" << expect;
+                QCOMPARE(actual.count(), expect.count());
+                QCOMPARE(actual, expect);
+            }
+        }
     }
 #endif
 }
