@@ -38,22 +38,22 @@
 using namespace KContacts;
 
 // template tags for address formatting localization
-#define KCONTACTS_FMTTAG_realname   QString::fromLatin1("%n")
-#define KCONTACTS_FMTTAG_REALNAME   QString::fromLatin1("%N")
-#define KCONTACTS_FMTTAG_company    QString::fromLatin1("%cm")
-#define KCONTACTS_FMTTAG_COMPANY    QString::fromLatin1("%CM")
-#define KCONTACTS_FMTTAG_pobox      QString::fromLatin1("%p")
-#define KCONTACTS_FMTTAG_street     QString::fromLatin1("%s")
-#define KCONTACTS_FMTTAG_STREET     QString::fromLatin1("%S")
-#define KCONTACTS_FMTTAG_zipcode    QString::fromLatin1("%z")
-#define KCONTACTS_FMTTAG_location   QString::fromLatin1("%l")
-#define KCONTACTS_FMTTAG_LOCATION   QString::fromLatin1("%L")
-#define KCONTACTS_FMTTAG_region     QString::fromLatin1("%r")
-#define KCONTACTS_FMTTAG_REGION     QString::fromLatin1("%R")
-#define KCONTACTS_FMTTAG_newline    QString::fromLatin1("\\n")
-#define KCONTACTS_FMTTAG_condcomma  QString::fromLatin1("%,")
-#define KCONTACTS_FMTTAG_condwhite  QString::fromLatin1("%w")
-#define KCONTACTS_FMTTAG_purgeempty QString::fromLatin1("%0")
+#define KCONTACTS_FMTTAG_realname   QStringLiteral("%n")
+#define KCONTACTS_FMTTAG_REALNAME   QStringLiteral("%N")
+#define KCONTACTS_FMTTAG_company    QStringLiteral("%cm")
+#define KCONTACTS_FMTTAG_COMPANY    QStringLiteral("%CM")
+#define KCONTACTS_FMTTAG_pobox      QStringLiteral("%p")
+#define KCONTACTS_FMTTAG_street     QStringLiteral("%s")
+#define KCONTACTS_FMTTAG_STREET     QStringLiteral("%S")
+#define KCONTACTS_FMTTAG_zipcode    QStringLiteral("%z")
+#define KCONTACTS_FMTTAG_location   QStringLiteral("%l")
+#define KCONTACTS_FMTTAG_LOCATION   QStringLiteral("%L")
+#define KCONTACTS_FMTTAG_region     QStringLiteral("%r")
+#define KCONTACTS_FMTTAG_REGION     QStringLiteral("%R")
+#define KCONTACTS_FMTTAG_newline    QStringLiteral("\\n")
+#define KCONTACTS_FMTTAG_condcomma  QStringLiteral("%,")
+#define KCONTACTS_FMTTAG_condwhite  QStringLiteral("%w")
+#define KCONTACTS_FMTTAG_purgeempty QStringLiteral("%0")
 
 /**
   Finds the balanced closing bracket starting from the opening bracket at
@@ -114,7 +114,7 @@ static bool parseAddressTemplateSection(const QString &tsection, QString &result
                 if (purge) {
                     // purge -> remove all
                     // replace with !_P_!, so conditional tags work later
-                    result.replace(fpos, bpos2 - fpos + 1, QLatin1String("!_P_!"));
+                    result.replace(fpos, bpos2 - fpos + 1, QStringLiteral("!_P_!"));
                     // leave stpos as it is
                 } else {
                     // no purge -> replace with recursively parsed string
@@ -136,8 +136,8 @@ static bool parseAddressTemplateSection(const QString &tsection, QString &result
     // The following macro needs QString for R_FIELD
     // It substitutes !_P_! for empty fields so conditional tags work later
 #define REPLTAG(R_TAG,R_FIELD) \
-    if ( result.indexOf( R_TAG, false ) != -1 ) { \
-        QString rpl = R_FIELD.isEmpty() ? QLatin1String( "!_P_!" ) : R_FIELD; \
+    if ( result.indexOf( R_TAG ) != -1 ) { \
+        QString rpl = R_FIELD.isEmpty() ? QStringLiteral( "!_P_!" ) : R_FIELD; \
         result.replace( R_TAG, rpl ); \
         if ( !R_FIELD.isEmpty() ) { \
             ret = true; \
@@ -164,7 +164,7 @@ static bool parseAddressTemplateSection(const QString &tsection, QString &result
         const QString str1 = result.mid(fpos - 5, 5);
         const QString str2 = result.mid(fpos + 2, 5);
         if (str1 != QLatin1String("!_P_!") && str2 != QLatin1String("!_P_!")) {
-            result.replace(fpos, 2, QLatin1String(", "));
+            result.replace(fpos, 2, QStringLiteral(", "));
         } else {
             result.remove(fpos, 2);
         }
@@ -176,7 +176,7 @@ static bool parseAddressTemplateSection(const QString &tsection, QString &result
         const QString str1 = result.mid(fpos - 5, 5);
         const QString str2 = result.mid(fpos + 2, 5);
         if (str1 != QLatin1String("!_P_!") && str2 != QLatin1String("!_P_!")) {
-            result.replace(fpos, 2, QLatin1String(" "));
+            result.replace(fpos, 2, QStringLiteral(" "));
         } else {
             result.remove(fpos, 2);
         }
@@ -184,12 +184,12 @@ static bool parseAddressTemplateSection(const QString &tsection, QString &result
     }
 
     // remove purged:
-    result.remove(QLatin1String("!_P_!"));
+    result.remove(QStringLiteral("!_P_!"));
 
     return ret;
 }
 
-class Address::Private : public QSharedData
+class Q_DECL_HIDDEN Address::Private : public QSharedData
 {
 public:
     Private()
@@ -533,18 +533,18 @@ QString Address::toString() const
     QString str;
 
     str += QLatin1String("Address {\n");
-    str += QString::fromLatin1("  IsEmpty: %1\n").
-           arg(d->mEmpty ? QLatin1String("true") : QLatin1String("false"));
-    str += QString::fromLatin1("  Id: %1\n").arg(d->mId);
-    str += QString::fromLatin1("  Type: %1\n").arg(typeLabel(d->mType));
-    str += QString::fromLatin1("  Post office box: %1\n").arg(d->mPostOfficeBox);
-    str += QString::fromLatin1("  Extended: %1\n").arg(d->mExtended);
-    str += QString::fromLatin1("  Street: %1\n").arg(d->mStreet);
-    str += QString::fromLatin1("  Locality: %1\n").arg(d->mLocality);
-    str += QString::fromLatin1("  Region: %1\n").arg(d->mRegion);
-    str += QString::fromLatin1("  Postal code: %1\n").arg(d->mPostalCode);
-    str += QString::fromLatin1("  Country: %1\n").arg(d->mCountry);
-    str += QString::fromLatin1("  Label: %1\n").arg(d->mLabel);
+    str += QStringLiteral("  IsEmpty: %1\n").
+           arg(d->mEmpty ? QStringLiteral("true") : QStringLiteral("false"));
+    str += QStringLiteral("  Id: %1\n").arg(d->mId);
+    str += QStringLiteral("  Type: %1\n").arg(typeLabel(d->mType));
+    str += QStringLiteral("  Post office box: %1\n").arg(d->mPostOfficeBox);
+    str += QStringLiteral("  Extended: %1\n").arg(d->mExtended);
+    str += QStringLiteral("  Street: %1\n").arg(d->mStreet);
+    str += QStringLiteral("  Locality: %1\n").arg(d->mLocality);
+    str += QStringLiteral("  Region: %1\n").arg(d->mRegion);
+    str += QStringLiteral("  Postal code: %1\n").arg(d->mPostalCode);
+    str += QStringLiteral("  Country: %1\n").arg(d->mCountry);
+    str += QStringLiteral("  Label: %1\n").arg(d->mLabel);
     str += QLatin1String("}\n");
 
     return str;
@@ -583,7 +583,7 @@ QString Address::formattedAddress(const QString &realName,
         qCWarning(KCONTACTS_LOG) << "address format database incomplete"
                                  << "(no format for locale" << ciso
                                  << "found). Using default address formatting.";
-        addrTemplate = QLatin1String("%0(%n\\n)%0(%cm\\n)%0(%s\\n)%0(PO BOX %p\\n)%0(%l%w%r)%,%z");
+        addrTemplate = QStringLiteral("%0(%n\\n)%0(%cm\\n)%0(%s\\n)%0(PO BOX %p\\n)%0(%l%w%r)%,%z");
     }
 
     // scan
@@ -626,7 +626,7 @@ QString Address::countryToISO(const QString &cname)
         return it.value();
     }
 
-    QString mapfile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kf5/kcontacts/countrytransl.map"));
+    QString mapfile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/kcontacts/countrytransl.map"));
     if (mapfile.isEmpty()) {
         qWarning() << "Installation error, couldn't find the countrytransl.map file";
     }
@@ -660,7 +660,7 @@ QString Address::ISOtoCountry(const QString &ISOname)
         return QString();
     }
 
-    QString mapfile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kf5/kabc/countrytransl.map"));
+    QString mapfile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/kabc/countrytransl.map"));
 
     QFile file(mapfile);
     if (file.open(QIODevice::ReadOnly)) {
