@@ -1,42 +1,49 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2015-2019 Laurent Montel <montel@kde.org>
+    Copyright (c) 2015 Laurent Montel <montel@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef CALENDARURL_H
 #define CALENDARURL_H
 #include "kcontacts_export.h"
 
-#include <QMap>
-#include <QSharedDataPointer>
-#include <QString>
+#include <QtCore/QSharedDataPointer>
+#include <QtCore/QString>
+#include <QtCore/QMap>
 class QUrl;
-
-class CalendarUrlTest;
-
-namespace KContacts
-{
-class ParameterMap;
-
 /** @short Class that holds a Calendar Url (FBURL/CALADRURI/CALURI)
  *  @since 4.14.6
  */
+
+namespace KContacts
+{
+
 class KCONTACTS_EXPORT CalendarUrl
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const CalendarUrl &);
     friend KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &, CalendarUrl &);
-    friend class VCardTool;
-    friend class ::CalendarUrlTest;
-
 public:
     enum CalendarType {
         Unknown = 0,
         FBUrl,
         CALUri,
         CALADRUri,
-        EndCalendarType,
+        EndCalendarType
     };
 
     CalendarUrl();
@@ -47,43 +54,24 @@ public:
 
     typedef QVector<CalendarUrl> List;
 
-    Q_REQUIRED_RESULT bool isValid() const;
+    bool isValid() const;
 
     void setType(CalendarUrl::CalendarType type);
-    Q_REQUIRED_RESULT CalendarUrl::CalendarType type() const;
+    CalendarUrl::CalendarType type() const;
 
     void setUrl(const QUrl &url);
     QUrl url() const;
 
-#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
-    /**
-     * @deprecated Since 5.88 for lack of usage
-     */
-    KCONTACTS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
     void setParameters(const QMap<QString, QStringList> &params);
-#endif
-
-#if KCONTACTS_ENABLE_DEPRECATED_SINCE(5, 88)
-    /**
-     * @deprecated Since 5.88 for lack of usage
-     */
-    Q_REQUIRED_RESULT
-    KCONTACTS_DEPRECATED_VERSION(5, 88, "For lack of usage.")
     QMap<QString, QStringList> parameters() const;
-#endif
 
-    Q_REQUIRED_RESULT bool operator==(const CalendarUrl &other) const;
-    Q_REQUIRED_RESULT bool operator!=(const CalendarUrl &other) const;
+    bool operator==(const CalendarUrl &other) const;
+    bool operator!=(const CalendarUrl &other) const;
 
     CalendarUrl &operator=(const CalendarUrl &other);
 
-    Q_REQUIRED_RESULT QString toString() const;
-
+    QString toString() const;
 private:
-    // exported for CalendarUrlTest
-    void setParams(const ParameterMap &params);
-    Q_REQUIRED_RESULT ParameterMap params() const;
-
     class Private;
     QSharedDataPointer<Private> d;
 };
@@ -91,6 +79,7 @@ private:
 KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &stream, const CalendarUrl &object);
 
 KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &stream, CalendarUrl &object);
+
 }
 Q_DECLARE_TYPEINFO(KContacts::CalendarUrl, Q_MOVABLE_TYPE);
 #endif // CALENDARURL_H
